###################
Python internal API
###################

.. automodapi:: neophile
   :include-all-objects:

.. automodapi:: neophile.analysis.base

.. automodapi:: neophile.analysis.pre_commit

.. automodapi:: neophile.analysis.python

.. automodapi:: neophile.cli

.. automodapi:: neophile.config

.. automodapi:: neophile.exceptions

.. automodapi:: neophile.factory

.. automodapi:: neophile.inventory.github

.. automodapi:: neophile.inventory.version

.. automodapi:: neophile.models.dependencies

.. automodapi:: neophile.pr

.. automodapi:: neophile.processor

.. automodapi:: neophile.repository

.. automodapi:: neophile.scanner.base

.. automodapi:: neophile.scanner.pre_commit

.. automodapi:: neophile.update.base

.. automodapi:: neophile.update.pre_commit

.. automodapi:: neophile.update.python
